@@ -124,7 +124,9 @@ trait FilterLogic<T: Eq + Copy> {
     ) -> PyResult<Option<(Option<&'py PyAny>, Option<&'py PyAny>)>> {
         let mut next_exclude: Option<&PyAny> = None;
         if let Some(exclude) = exclude {
-            if let Ok(exclude_dict) = exclude.downcast::<PyDict>() {
+            if exclude.is_none() {
+                // Do nothing; place this check at the top for performance in the common case
+            } else if let Ok(exclude_dict) = exclude.downcast::<PyDict>() {
                 let op_exc_value = merge_all_value(exclude_dict, py_key)?;
                 if let Some(exc_value) = op_exc_value {
                     if is_ellipsis_like(exc_value) {
@@ -141,13 +143,19 @@ trait FilterLogic<T: Eq + Copy> {
                     // index is in the exclude set, we return Ok(None) to omit this index
                     return Ok(None);
                 }
-            } else if !exclude.is_none() {
-                return Err(PyTypeError::new_err("`exclude` argument must a set or dict."));
+            } else if let Some(contains) = check_contains(exclude, py_key)? {
+                if contains {
+                    return Ok(None);
+                }
+            } else {
+                return Err(PyTypeError::new_err("`exclude` argument must be a set or dict."));
             }
         }
 
         if let Some(include) = include {
-            if let Ok(include_dict) = include.downcast::<PyDict>() {
+            if include.is_none() {
+                // Do nothing; place this check at the top for performance in the common case
+            } else if let Ok(include_dict) = include.downcast::<PyDict>() {
                 let op_inc_value = merge_all_value(include_dict, py_key)?;
 
                 if let Some(inc_value) = op_inc_value {
@@ -170,8 +178,16 @@ trait FilterLogic<T: Eq + Copy> {
                     // this index should be omitted
                     return Ok(None);
                 }
-            } else if !include.is_none() {
-                return Err(PyTypeError::new_err("`include` argument must a set or dict."));
+            } else if let Some(contains) = check_contains(include, py_key)? {
+                if contains {
+                    return Ok(Some((None, next_exclude)));
+                } else if !self.explicit_include(int_key) {
+                    // if the index is not in include, include exists, AND it's not in schema include,
+                    // this index should be omitted
+                    return Ok(None);
+                }
+            } else {
+                return Err(PyTypeError::new_err("`include` argument must be a set or dict."));
             }
         }
 
@@ -234,6 +250,24 @@ impl AnyFilter {
     }
 }
 
+/// if a `__contains__` method exists, call it with the key and `__all__`, and return the result
+/// if it doesn't exist, or calling it fails (e.g. it's not a function), return `None`
+fn check_contains(obj: &PyAny, py_key: impl ToPyObject + Copy) -> PyResult<Option<bool>> {
+    let py = obj.py();
+    match obj.getattr(intern!(py, "__contains__")) {
+        Ok(contains_method) => {
+            if let Ok(result) = contains_method.call1((py_key.to_object(py),)) {
+                Ok(Some(
+                    result.is_true()? || contains_method.call1((intern!(py, "__all__"),))?.is_true()?,
+                ))
+            } else {
+                Ok(None)
+            }
+        }
+        Err(_) => Ok(None),
+    }
+}
+
 impl<T> FilterLogic<T> for AnyFilter
 where
     T: Eq + Copy,
