@@ -1,7 +1,7 @@
 import dataclasses
 import json
 import platform
-from typing import ClassVar
+from typing import Any, ClassVar
 
 import pytest
 
@@ -395,3 +395,54 @@ def test_advanced_exclude_nested_lists(exclude, expected):
     s = SchemaSerializer(model_schema)
 
     assert s.to_python(data, exclude=exclude) == expected
+
+
+def test_function_plain_field_serializer():
+    @dataclasses.dataclass
+    class Model:
+        x: int
+
+        def ser_x(self, v: Any, _) -> str:
+            return f'{v:_}'
+
+    s = SchemaSerializer(
+        core_schema.model_schema(
+            Model,
+            core_schema.typed_dict_schema(
+                {
+                    'x': core_schema.typed_dict_field(
+                        core_schema.int_schema(serialization=core_schema.field_function_plain_ser_schema(Model.ser_x))
+                    )
+                }
+            ),
+        )
+    )
+    assert s.to_python(Model(x=1000)) == {'x': '1_000'}
+
+
+def test_function_wrap_field_serializer():
+    @dataclasses.dataclass
+    class Model:
+        x: int
+
+        def ser_x(self, v: Any, serializer: core_schema.SerializeWrapHandler, _) -> str:
+            x = serializer(v)
+            return f'{x:_}'
+
+    s = SchemaSerializer(
+        core_schema.model_schema(
+            Model,
+            core_schema.typed_dict_schema(
+                {
+                    'x': core_schema.typed_dict_field(
+                        core_schema.int_schema(
+                            serialization=core_schema.field_function_wrap_ser_schema(
+                                Model.ser_x, schema=core_schema.any_schema()
+                            )
+                        )
+                    )
+                }
+            ),
+        )
+    )
+    assert s.to_python(Model(x=1000)) == {'x': '1_000'}
