@@ -16,20 +16,22 @@ def test_chain():
 
 
 def test_function_plain():
-    s = SchemaSerializer(core_schema.function_plain_schema(lambda v, info: v + 1))
+    s = SchemaSerializer(core_schema.general_plain_validation_function(lambda v, info: v + 1))
     # can't infer the type from plain function validators
     # insert_assert(plain_repr(s))
     assert plain_repr(s) == 'SchemaSerializer(serializer=Any(AnySerializer),slots=[])'
 
 
 def test_function_before():
-    s = SchemaSerializer(core_schema.function_before_schema(lambda v, info: v + 1, core_schema.int_schema()))
+    s = SchemaSerializer(
+        core_schema.general_before_validation_function(lambda v, info: v + 1, core_schema.int_schema())
+    )
     # insert_assert(plain_repr(s))
     assert plain_repr(s) == 'SchemaSerializer(serializer=Int(IntSerializer),slots=[])'
 
 
 def test_function_after():
-    s = SchemaSerializer(core_schema.function_after_schema(core_schema.int_schema(), lambda v, info: v + 1))
+    s = SchemaSerializer(core_schema.general_after_validation_function(lambda v, info: v + 1, core_schema.int_schema()))
     # insert_assert(plain_repr(s))
     assert plain_repr(s) == 'SchemaSerializer(serializer=Int(IntSerializer),slots=[])'
 
