@@ -36,7 +36,7 @@ def test_pydantic_value_error_usage():
     def f(input_value, info):
         raise PydanticCustomError('my_error', 'this is a custom error {foo} {bar}', {'foo': 'FOOBAR', 'bar': 42})
 
-    v = SchemaValidator({'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': f}})
+    v = SchemaValidator({'type': 'function-plain', 'function': {'type': 'general', 'function': f}})
 
     with pytest.raises(ValidationError) as exc_info:
         v.validate_python(42)
@@ -56,7 +56,7 @@ def test_pydantic_value_error_invalid_dict():
     def my_function(input_value, info):
         raise PydanticCustomError('my_error', 'this is a custom error {foo}', {(): 'foobar'})
 
-    v = SchemaValidator({'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': my_function}})
+    v = SchemaValidator({'type': 'function-plain', 'function': {'type': 'general', 'function': my_function}})
 
     with pytest.raises(ValidationError) as exc_info:
         v.validate_python(42)
@@ -74,7 +74,7 @@ def test_pydantic_value_error_invalid_type():
     def f(input_value, info):
         raise PydanticCustomError('my_error', 'this is a custom error {foo}', [('foo', 123)])
 
-    v = SchemaValidator({'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': f}})
+    v = SchemaValidator({'type': 'function-plain', 'function': {'type': 'general', 'function': f}})
 
     with pytest.raises(TypeError, match="argument 'context': 'list' object cannot be converted to 'PyDict'"):
         v.validate_python(42)
@@ -91,12 +91,7 @@ def test_validator_instance_plain():
 
     c = CustomValidator()
     v = SchemaValidator(
-        {
-            'type': 'function',
-            'mode': 'plain',
-            'metadata': {'instance': c},
-            'function': {'type': 'general', 'function': c.validate},
-        }
+        {'type': 'function-plain', 'metadata': {'instance': c}, 'function': {'type': 'general', 'function': c.validate}}
     )
     c.foo += 1
 
@@ -117,8 +112,7 @@ def test_validator_instance_after():
     c = CustomValidator()
     v = SchemaValidator(
         {
-            'type': 'function',
-            'mode': 'after',
+            'type': 'function-after',
             'metadata': {'instance': c},
             'function': {'type': 'general', 'function': c.validate},
             'schema': {'type': 'str'},
@@ -144,12 +138,7 @@ def test_pydantic_error_type_raise_no_ctx():
         raise PydanticKnownError('finite_number')
 
     v = SchemaValidator(
-        {
-            'type': 'function',
-            'mode': 'before',
-            'function': {'type': 'general', 'function': f},
-            'schema': {'type': 'int'},
-        }
+        {'type': 'function-before', 'function': {'type': 'general', 'function': f}, 'schema': {'type': 'int'}}
     )
 
     with pytest.raises(ValidationError) as exc_info:
@@ -165,12 +154,7 @@ def test_pydantic_error_type_raise_ctx():
         raise PydanticKnownError('greater_than', {'gt': 42})
 
     v = SchemaValidator(
-        {
-            'type': 'function',
-            'mode': 'before',
-            'function': {'type': 'general', 'function': f},
-            'schema': {'type': 'int'},
-        }
+        {'type': 'function-before', 'function': {'type': 'general', 'function': f}, 'schema': {'type': 'int'}}
     )
 
     with pytest.raises(ValidationError) as exc_info:
@@ -320,7 +304,7 @@ def test_pydantic_value_error_plain(py_and_json: PyAndJson):
     def f(input_value, info):
         raise PydanticCustomError
 
-    v = py_and_json({'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': f}})
+    v = py_and_json({'type': 'function-plain', 'function': {'type': 'general', 'function': f}})
     with pytest.raises(TypeError, match='missing 2 required positional arguments'):
         v.validate_test('4')
 
@@ -336,9 +320,8 @@ def test_list_omit_exception(py_and_json: PyAndJson, exception):
         {
             'type': 'list',
             'items_schema': {
-                'type': 'function',
+                'type': 'function-after',
                 'schema': {'type': 'int'},
-                'mode': 'after',
                 'function': {'type': 'general', 'function': f},
             },
         }
