@@ -67,9 +67,9 @@ def test_schema_typing() -> None:
     SchemaValidator(schema)
     schema: CoreSchema = {'type': 'set', 'items_schema': {'type': 'str'}, 'max_length': 3}
     SchemaValidator(schema)
-    schema: CoreSchema = {'type': 'tuple', 'mode': 'variable', 'items_schema': {'type': 'str'}, 'max_length': 3}
+    schema: CoreSchema = {'type': 'tuple-variable', 'items_schema': {'type': 'str'}, 'max_length': 3}
     SchemaValidator(schema)
-    schema: CoreSchema = {'type': 'tuple', 'mode': 'positional', 'items_schema': [{'type': 'str'}, {'type': 'int'}]}
+    schema: CoreSchema = {'type': 'tuple-positional', 'items_schema': [{'type': 'str'}, {'type': 'int'}]}
     SchemaValidator(schema)
     schema: CoreSchema = {'type': 'frozenset', 'items_schema': {'type': 'str'}, 'max_length': 3}
     SchemaValidator(schema)
@@ -92,13 +92,12 @@ def test_schema_typing() -> None:
     }
     SchemaValidator(schema)
     schema: CoreSchema = {
-        'type': 'function',
-        'mode': 'wrap',
+        'type': 'function-wrap',
         'function': {'type': 'general', 'function': wrap_validator},
         'schema': {'type': 'str'},
     }
     SchemaValidator(schema)
-    schema: CoreSchema = {'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': validator}}
+    schema: CoreSchema = {'type': 'function-plain', 'function': {'type': 'general', 'function': validator}}
     SchemaValidator(schema)
     schema: CoreSchema = {
         'ref': 'Branch',
@@ -201,7 +200,7 @@ def test_ser_function_plain():
         return str(__info)
 
     s = SchemaSerializer(
-        core_schema.any_schema(serialization=core_schema.function_plain_ser_schema(f, json_return_type='str'))
+        core_schema.any_schema(serialization=core_schema.general_function_plain_ser_schema(f, json_return_type='str'))
     )
     assert s.to_python(123) == (
         "SerializationInfo(include=None, exclude=None, mode='python', by_alias=True, exclude_unset=False, "
@@ -215,7 +214,7 @@ def test_ser_function_wrap():
 
     s = SchemaSerializer(
         core_schema.any_schema(
-            serialization=core_schema.function_wrap_ser_schema(f, core_schema.str_schema(), when_used='json')
+            serialization=core_schema.general_function_wrap_ser_schema(f, core_schema.str_schema(), when_used='json')
         )
     )
     # insert_assert(s.to_python(123, mode='json'))
