@@ -42,7 +42,7 @@ def test_def_error():
             )
         )
     assert exc_info.value.args[0].startswith(
-        "Invalid Schema:\ndefinitions -> definitions -> 1\n  Input tag 'wrong' found using self-schema"
+        "Invalid Schema:\ndefinitions -> definitions -> 1\n  Input tag 'wrong' found using 'type'"
     )
 
 
